#[non_exhaustive]pub struct FlatCluster {
pub id: ClusterId,
pub parent_id: Option<ClusterId>,
pub label: String,
pub axis: String,
pub value: Value,
pub total: u64,
pub score_min: Option<f64>,
pub score_max: Option<f64>,
}Expand description
Flat cluster form (7.1).
Equivalent in content to Cluster but with parent_id replacing
the recursive clusters array.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: ClusterIdCluster id from the root to this cluster.
parent_id: Option<ClusterId>Parent id, or None for top-level clusters.
label: StringHuman-readable label.
axis: StringField path for this cluster’s axis.
value: ValueRaw value behind this cluster.
total: u64Number of input items inside this cluster (recursively).
score_min: Option<f64>Minimum score within this cluster, when a score path is in use.
score_max: Option<f64>Maximum score within this cluster, when a score path is in use.