#[non_exhaustive]pub struct ScoreOptions {
pub candidates: Vec<String>,
}Expand description
Tunable inputs for 4.3 score-field detection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.candidates: Vec<String>Candidate field names preferred before the unique-numeric fallback. Names are matched at the top level first, then at any nested object depth, in this order.