SkipReason

Enum SkipReason 

#[non_exhaustive]
pub enum SkipReason { InvalidJson { column: usize, message: String, }, MissingField { field: String, }, WrongType { field: String, kind: String, }, NonNumericScore { path: String, value_summary: String, }, }
Reason a single input record was skipped during processing.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidJson

The record could not be parsed as JSON.

Fields

column: usize

Column at which the parser failed.

message: String

Parser error message.



MissingField

The record parsed but a required field was missing.

Fields

field: String

Field path that was missing.



WrongType

The record had a value at the field path but the value’s JSON kind was not usable for the strategy at hand. Distinct from SkipReason::MissingField — the field is present, just the wrong shape (e.g. an array where the strategy expects a scalar key).

Fields

field: String

Field path that resolved to a value of the wrong shape.

kind: String

Lowercase JSON kind name: array, object, string, boolean, number, null.



NonNumericScore

The record had a value at the score path but it was not numeric.

Fields

path: String

Score path that resolved to a non-numeric value.

value_summary: String

Short rendering of the offending value for the stderr line.